@@ -6,7 +6,7 @@
  *
  * perdition
  * Mail retrieval proxy server, NIS support
- * Copyright (C) 2000-2001 Nathan Neulinge and Horms
+ * Copyright (C) 1999-2004 Nathan Neulinge and Horms
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -35,8 +35,8 @@
 #define PERDITIONDB_NIS_DEFAULT_MAPNAME "user_mail_server"
 
 int dbserver_get(
-  char *key_str, 
-  char *options_str,
+  const char *key_str, 
+  const char *options_str,
   char **str_return, 
   int *len_return
 );
