@@ -1,12 +1,12 @@
 /**********************************************************************
  * imap4.h                                               September 1999
- * Horms                                             horms@vergenet.net
+ * Horms                                             horms@verge.net.au
  *
  * IMAP4 protocol defines
  *
  * perdition
  * Mail retrieval proxy server
- * Copyright (C) 1999-2001  Horms
+ * Copyright (C) 1999-2004  Horms
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -25,8 +25,8 @@
  *
  **********************************************************************/
 
-#ifndef IMAP4_FLIM
-#define IMAP4_FLIM
+#ifndef _PERDITION_IMAP4_H
+#define _PERDITION_IMAP4_H
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -39,11 +39,31 @@
 #include "imap4_in.h"
 #include "imap4_out.h"
 
+
+/**********************************************************************
+ * imap4_initialise_protocol
+ * Initialise the protocol structure for the imap4 protocol
+ * Pre: protocol: pointer to an allocated protocol structure
+ * Post: Return seeded protocol stricture
+ *              NULL on error
+ **********************************************************************/
+
 protocol_t *imap4_initialise_protocol(protocol_t *protocol);
 
-void imap4_destroy_protocol(protocol_t *protocol);
 
-char *imap4_port(char *port);
+/**********************************************************************
+ * imap4_capability 
+ * Return the capability string to be used.
+ * pre: capability: capability string that has been set
+ *      mangled_capability: not used
+ *      tls_flags: the encryption flags that have been set
+ *      tls_state: the current state of encryption for the session
+ * post: capability to use, as per protocol_capability
+ *       with IMAP4 parameters
+ **********************************************************************/
+
+char *imap4_capability(char *capability, char **mangled_capability,
+		flag_t tls_flags, flag_t tls_mode);
+
 
 #endif
-
