@@ -1,12 +1,12 @@
 /**********************************************************************
  * quit.h                                                  October 1999
- * Horms                                             horms@vergenet.net
+ * Horms                                             horms@verge.net.au
  *
- * Protocol indepentant quit
+ * Protocol independent quit
  *
  * perdition
  * Mail retrieval proxy server
- * Copyright (C) 1999-2001  Horms
+ * Copyright (C) 1999-2004  Horms
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -37,13 +37,10 @@
 #include "config.h" 
 #endif
 
-#include "perdition_types.h"
-#include "imap4_write.h"
-#include "log.h"
 #include "protocol_t.h"
-#include "queue_func.h"
 #include "token.h"
+#include "io.h"
 
-int quit(io_t *io, const protocol_t *protocol);
+int quit(io_t *io, const protocol_t *protocol, token_t *tag);
 
 #endif
